@@ -401,12 +401,14 @@ public class DateTimeZoneBuilder {
     private boolean addTransition(ArrayList<Transition> transitions, Transition tr) {
         int size = transitions.size();
         if (size == 0) {
+//            System.out.println("Adding   " + tr);
             transitions.add(tr);
             return true;
         }
 
         Transition last = transitions.get(size - 1);
         if (!tr.isTransitionFrom(last)) {
+//            System.out.println("Rejected " + tr);
             return false;
         }
 
@@ -423,11 +425,15 @@ public class DateTimeZoneBuilder {
 
         if (newLocal != lastLocal) {
             transitions.add(tr);
+//            System.out.println("Adding   " + tr);
             return true;
         }
-
-        transitions.remove(size - 1);
-        return addTransition(transitions, tr);
+        Transition previous = transitions.remove(size - 1);
+        Transition adjusted = tr.withMillis(previous.getMillis());
+//        System.out.println("Current  " + tr);
+//        System.out.println("Previous " + previous);
+//        System.out.println("Adjusted " + adjusted);
+        return addTransition(transitions, adjusted);
     }
 
     /**
@@ -642,7 +648,6 @@ public class DateTimeZoneBuilder {
             return false;
         }
 
-        /*
         public String toString() {
             return
                 "[OfYear]\n" + 
@@ -653,7 +658,6 @@ public class DateTimeZoneBuilder {
                 "AdvanceDayOfWeek: " + iAdvance + '\n' +
                 "MillisOfDay: " + iMillisOfDay + '\n';
         }
-        */
 
         public void writeTo(DataOutput out) throws IOException {
             out.writeByte(iMode);
@@ -803,6 +807,11 @@ public class DateTimeZoneBuilder {
         Recurrence renameAppend(String appendNameKey) {
             return rename((iNameKey + appendNameKey).intern());
         }
+        
+        @Override
+        public String toString() {
+            return iOfYear + " named " + iNameKey + " at " + iSaveMillis;
+        }
     }
 
     /**
@@ -874,6 +883,11 @@ public class DateTimeZoneBuilder {
 
             return next;
         }
+        
+        @Override
+        public String toString() {
+            return iFromYear + " to " + iToYear + " using " + iRecurrence;
+        }
     }
 
     private static final class Transition {
@@ -924,6 +938,10 @@ public class DateTimeZoneBuilder {
             return iWallOffset - iStandardOffset;
         }
 
+        public Transition withMillis(long millis) {
+            return new Transition(millis, iNameKey, iWallOffset, iStandardOffset);
+        }
+
         /**
          * There must be a change in the millis, wall offsets or name keys.
          */
@@ -933,9 +951,14 @@ public class DateTimeZoneBuilder {
             }
             return iMillis > other.iMillis &&
                 (iWallOffset != other.iWallOffset ||
-                 //iStandardOffset != other.iStandardOffset ||
+                 iStandardOffset != other.iStandardOffset ||
                  !(iNameKey.equals(other.iNameKey)));
         }
+        
+        @Override
+        public String toString() {
+            return new DateTime(iMillis, DateTimeZone.UTC) + " " + iStandardOffset + " " + iWallOffset;
+        }
     }
 
     private static final class RuleSet {
@@ -1160,6 +1183,12 @@ public class DateTimeZoneBuilder {
             }
             return null;
         }
+        
+        @Override
+        public String toString() {
+            return iInitialNameKey + " initial: " + iInitialSaveMillis + " std: " + iStandardOffset +
+                    " upper: " + iUpperYear + " " + iUpperOfYear + " " + iRules;
+        }
     }
 
     private static final class DSTZone extends DateTimeZone {
