@@ -19,6 +19,7 @@ import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
+import java.math.RoundingMode;
 import java.util.Locale;
 import java.util.TimeZone;
 
@@ -704,6 +705,31 @@ public class TestDuration_Basics extends TestCase {
         assertSame(test, result);
     }
 
+    //-----------------------------------------------------------------------
+    public void testDividedByRoundingMode_long1() {
+        Duration test = new Duration(246L);
+        Duration result = test.dividedBy(2L, RoundingMode.UNNECESSARY);
+        assertEquals(123L, result.getMillis());
+    }
+
+    public void testDividedByRoundingMode_long2() {
+        Duration test = new Duration(123L);
+        Duration result = test.dividedBy(2L, RoundingMode.FLOOR);
+        assertEquals(61L, result.getMillis());
+    }
+
+    public void testDividedByRoundingMode_long3() {
+        Duration test = new Duration(123L);
+        Duration result = test.dividedBy(7L, RoundingMode.CEILING);
+        assertEquals(18L, result.getMillis());
+    }
+
+    public void testDividedByRoundingMode_long4() {
+        Duration test = new Duration(33L);
+        Duration result = test.dividedBy(1L, RoundingMode.FLOOR);
+        assertSame(test, result);
+    }
+
     //-----------------------------------------------------------------------
     public void testNegated_long1() {
         Duration test = new Duration(246L);
